@@ -4,7 +4,10 @@ class CannotFindPackagewithVersionProvided(Exception):
 	pass
 import requests,aiohttp
 def get(name):
-      r = requests.get(f"https://pypi.org/pypi/{name}/json")
+      try:
+      	r = requests.get(f"https://pypi.org/pypi/{name}/json")
+      except Exception:
+      	raise CannotFindPackage("Error occured!\nI can\'t get the package info maybe check your typo or check your connection if you check it was all right, pypi api may gone maintenance.")
       if r.status_code != 200:
              raise CannotFindPackage("Error occured!\nI can\'t get the package info maybe check your typo or check your connection if you check it was all right, pypi api may gone maintenance.")
              
@@ -12,7 +15,10 @@ def get(name):
              js = r.json()
              return js
 def getbyv(name,ver:str):
-      r = requests.get(f"https://pypi.org/pypi/{name}/{ver}/json")
+      try:
+      	r = requests.get(f"https://pypi.org/pypi/{name}/{ver}/json")
+      except Exception:
+      	raise CannotFindPackagewithVersionProvided("Error occured!\nI can\'t get the package info with provided version maybe check your typo or check your connection if you check it was all right, pypi api may gone maintenance.")
       if r.status_code != 200:
              raise CannotFindPackagewithVersionProvided("Error occured!\nI can\'t get the package info with provided version maybe check your typo or check your connection if you check it was all right, pypi api may gone maintenance.")
             
